# FAQ

Answers to common questions and solutions to frequent problems.

## Getting Help

If your issue isn't covered here:

1. Run `erk doctor` to check your environment
2. Check the [GitHub Issues](https://github.com/schrockn/erk/issues) for known problems
3. File a new issue with output from `erk doctor`

## See Also

- [Prerequisites](../tutorials/prerequisites.md) - Required tools and versions
